import React from "react";
import styles from "./index.less";
import { Button, Divider, Dropdown, InputNumber, Tooltip } from "antd";
import {
  AlignCenterOutlined,
  BoldOutlined,
  CaretDownOutlined,
  ColumnHeightOutlined,
  ItalicOutlined,
  UnderlineOutlined,
} from "@ant-design/icons";

export default function ToolBar() {
  return (
    <div className={styles.toolBar}>
      <div className="flex justify-between items-center">
        <div className="h-40px flex items-center">
          <Tooltip placement="bottom" title="撤销">
            <Button type="text" icon={<i className="iconfont icon-undo"></i>} />
          </Tooltip>

          <Tooltip placement="bottom" title="恢复">
            <Button
              type="text"
              icon={<i className="iconfont icon-redo"></i>}
              disabled
            />
          </Tooltip>

          <Tooltip placement="bottom" title="格式刷">
            <Button
              type="text"
              icon={<i className="iconfont icon-geshishua"></i>}
              disabled
            />
          </Tooltip>

          <Tooltip placement="bottom" title="美化">
            <Button
              type="text"
              icon={<i className="iconfont icon-mofabang"></i>}
            />
          </Tooltip>

          <Divider type="vertical" />

          <Dropdown menu={{ items: [] }}>
            <Tooltip placement="bottom" title="字体">
              <Button type="text" className="w-90px">
                <span className="font-">微软雅黑</span>
                <CaretDownOutlined />
              </Button>
            </Tooltip>
          </Dropdown>

          <Tooltip placement="bottom" title="字体大小">
            <InputNumber
              value="14"
              className="w-70px"
              variant="filled"
              formatter={(value) => `${value}px`}
            />
          </Tooltip>

          <Tooltip placement="bottom" title="字体加粗">
            <Button type="text" icon={<BoldOutlined />} />
          </Tooltip>

          <Tooltip placement="bottom" title="字体倾斜">
            <Button type="text" icon={<ItalicOutlined />} />
          </Tooltip>

          <Tooltip placement="bottom" title="下划线">
            <Button type="text" icon={<UnderlineOutlined />} />
          </Tooltip>

          <Tooltip placement="bottom" title="字体颜色">
            <Button
              type="text"
              icon={
                <div className="flex flex-col">
                  <span className="iconfont icon-A text-13px"></span>
                  <span
                    className="w-16px h-2px border-1px border-#ff0"
                    style={{ background: "#000" }}
                  ></span>
                </div>
              }
            />
          </Tooltip>

          <Dropdown menu={{ items: [] }}>
            <Tooltip placement="bottom" title="文本行高">
              <Button type="text" className="w-50px">
                <ColumnHeightOutlined />
                <CaretDownOutlined className="text-12px" />
              </Button>
            </Tooltip>
          </Dropdown>

          <Dropdown menu={{ items: [] }}>
            <Tooltip placement="bottom" title="文本对齐">
              <Button type="text" className="w-50px">
                <AlignCenterOutlined />
                <CaretDownOutlined className="text-12px" />
              </Button>
            </Tooltip>
          </Dropdown>
          <Divider type="vertical" />
          <Tooltip placement="bottom" title="颜色填充">
            <Button
              type="text"
              icon={
                <div className="flex flex-col">
                  <span className="iconfont icon-paint-bucket text-13px"></span>
                  <span
                    className="w-16px h-2px border-1px border-#ff0"
                    style={{ background: "#000" }}
                  ></span>
                </div>
              }
            />
          </Tooltip>

          <Tooltip placement="bottom" title="连线颜色">
            <Button
              type="text"
              icon={
                <div className="flex flex-col">
                  <span className="iconfont icon-bi text-13px"></span>
                  <span
                    className="w-16px h-2px border-1px border-#ff0"
                    style={{ background: "#000" }}
                  ></span>
                </div>
              }
            />
          </Tooltip>

          <Dropdown menu={{ items: [] }}>
            <Tooltip placement="bottom" title="连线宽度">
              <Button type="text" className="w-50px">
                <i className="iconfont icon-xiankuan"></i>
                <CaretDownOutlined className="text-12px" />
              </Button>
            </Tooltip>
          </Dropdown>

          <Dropdown menu={{ items: [] }}>
            <Tooltip placement="bottom" title="连线样式">
              <Button type="text" className="w-50px">
                <i className="iconfont icon-jixianyangshi-line"></i>
                <CaretDownOutlined className="text-12px" />
              </Button>
            </Tooltip>
          </Dropdown>

          <Dropdown menu={{ items: [] }}>
            <Tooltip placement="bottom" title="连线类型">
              <Button type="text" className="w-50px">
                <i className="iconfont icon-lianxian"></i>
                <CaretDownOutlined className="text-12px" />
              </Button>
            </Tooltip>
          </Dropdown>
          <Divider type="vertical" />

          <Dropdown menu={{ items: [] }}>
            <Tooltip placement="bottom" title="图层排列">
              <Button type="text" className="w-50px">
                <i className="iconfont icon-zhiding1"></i>
                <CaretDownOutlined className="text-12px" />
              </Button>
            </Tooltip>
          </Dropdown>

          <Dropdown menu={{ items: [] }}>
            <Tooltip placement="bottom" title="宽高匹配">
              <Button type="text" className="w-50px">
                <i className="iconfont icon-kuandu"></i>
                <CaretDownOutlined className="text-12px" />
              </Button>
            </Tooltip>
          </Dropdown>
        </div>
      </div>
    </div>
  );
}
